from setuptools import setup

setup(name='vvs_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['vvs_distributions'],
      author = 'Vamsee Sundar',
      author_email = 'vvippart@asu.edu',
      zip_safe=False)
